@@ -1,4 +1,4 @@
-import System.Cmd (system)
+import System.Process (system)
 import System.Exit (exitWith)
 
 main = system "make -k -C tests clean all" >>= exitWith
